@@ -477,6 +477,9 @@ def status(ctx, container_name, format):
 
         ctx.exit(0)
 
+    except (click.exceptions.Exit, SystemExit, KeyboardInterrupt):
+        # Let Click handle these - don't catch them
+        raise
     except Exception as e:
         if format == "json":
             print(json.dumps({"error": str(e)}))
@@ -630,3 +633,212 @@ def remove(ctx, container_name, force, volumes):
     except Exception as e:
         progress.print_error(f"Failed to remove container: {e}")
         ctx.exit(1)
+
+
+@container_group.command(name="reset-password")
+@click.argument("container_name")
+@click.option(
+    "--user",
+    default="_SYSTEM",
+    help="Username to reset password for (default: _SYSTEM)"
+)
+@click.option(
+    "--password",
+    default="SYS",
+    help="New password (default: SYS)"
+)
+@click.pass_context
+def reset_password_cmd(ctx, container_name, user, password):
+    """
+    Reset password for IRIS user in container.
+
+    Uses iris session to reset the password via ObjectScript.
+
+    \b
+    Examples:
+        # Reset _SYSTEM password to SYS
+        iris-devtester container reset-password my_iris
+
+        # Reset specific user password
+        iris-devtester container reset-password my_iris --user admin --password newpass
+    """
+    try:
+        from iris_devtester.utils.password_reset import reset_password
+
+        click.echo(f"⚡ Resetting password for user '{user}' in container '{container_name}'...")
+
+        # Call password reset utility
+        success, message = reset_password(
+            container_name=container_name,
+            username=user,
+            new_password=password
+        )
+
+        if success:
+            click.echo(f"✓ Password reset successful for user '{user}'")
+            ctx.exit(0)
+        else:
+            progress.print_error(f"Failed to reset password: {message}")
+            ctx.exit(1)
+
+    except (ImportError, ModuleNotFoundError) as e:
+        progress.print_error(f"password_reset utility not available: {e}")
+        ctx.exit(1)
+    except (click.exceptions.Exit, SystemExit, KeyboardInterrupt):
+        # Let Click handle these - don't catch them
+        raise
+    except Exception as e:
+        progress.print_error(f"Failed to reset password: {e}")
+        ctx.exit(1)
+
+
+@container_group.command(name="test-connection")
+@click.argument("container_name")
+@click.option(
+    "--namespace",
+    default="USER",
+    help="IRIS namespace to test connection to (default: USER)"
+)
+@click.option(
+    "--username",
+    default="_SYSTEM",
+    help="Username for connection (default: _SYSTEM)"
+)
+@click.option(
+    "--password",
+    default="SYS",
+    help="Password for connection (default: SYS)"
+)
+@click.pass_context
+def test_connection_cmd(ctx, container_name, namespace, username, password):
+    """
+    Test database connection to IRIS container.
+
+    Verifies that DBAPI connection works to the specified container and namespace.
+
+    \b
+    Examples:
+        # Test connection to default namespace (USER)
+        iris-devtester container test-connection my_iris
+
+        # Test connection to specific namespace
+        iris-devtester container test-connection my_iris --namespace MYAPP
+
+        # Test with custom credentials
+        iris-devtester container test-connection my_iris --user admin --password secret
+    """
+    try:
+        from iris_devtester.config import IRISConfig
+        from iris_devtester.connections import get_connection
+
+        click.echo(f"⚡ Testing connection to container '{container_name}' namespace '{namespace}'...")
+
+        # Get container to extract connection details
+        container = IRISContainerManager.get_existing(container_name)
+
+        if not container:
+            progress.print_error(f"Container '{container_name}' not found")
+            ctx.exit(2)
+
+        # Get port mappings
+        container.reload()
+        port_bindings = container.attrs.get("NetworkSettings", {}).get("Ports", {})
+
+        # Extract superserver port
+        superserver_port = 1972  # Default
+        if "1972/tcp" in port_bindings and port_bindings["1972/tcp"]:
+            superserver_port = int(port_bindings["1972/tcp"][0]["HostPort"])
+
+        # Create configuration
+        config = IRISConfig(
+            host="localhost",
+            port=superserver_port,
+            namespace=namespace,
+            username=username,
+            password=password,
+            driver="auto"
+        )
+
+        # Try to connect
+        try:
+            conn = get_connection(config)
+
+            # Test the connection with a simple query
+            cursor = conn.cursor()
+            cursor.execute("SELECT $NAMESPACE as namespace")
+            result = cursor.fetchone()
+            cursor.close()
+            conn.close()
+
+            click.echo(f"✓ Connection successful to namespace '{namespace}'")
+            click.echo(f"  Host: {config.host}:{config.port}")
+            click.echo(f"  Namespace: {namespace}")
+            click.echo(f"  User: {username}")
+            ctx.exit(0)
+
+        except (click.exceptions.Exit, SystemExit, KeyboardInterrupt):
+            # Let Click handle these - don't catch them
+            raise
+        except Exception as e:
+            progress.print_error(f"Connection failed: {e}")
+            ctx.exit(1)
+
+    except (click.exceptions.Exit, SystemExit, KeyboardInterrupt):
+        # Let Click handle these - don't catch them
+        raise
+    except Exception as e:
+        progress.print_error(f"Failed to test connection: {e}")
+        ctx.exit(1)
+
+
+@container_group.command(name="enable-callin")
+@click.argument("container_name")
+@click.option(
+    "--timeout",
+    type=int,
+    default=30,
+    help="Timeout in seconds for docker commands (default: 30)"
+)
+@click.pass_context
+def enable_callin(ctx, container_name, timeout):
+    """
+    Enable CallIn service in IRIS container.
+
+    Required for DBAPI connections to work properly.
+
+    \b
+    Examples:
+        # Enable CallIn service
+        iris-devtester container enable-callin my_iris
+
+        # With longer timeout
+        iris-devtester container enable-callin my_iris --timeout 60
+    """
+    try:
+        from iris_devtester.utils.enable_callin import enable_callin_service
+
+        click.echo(f"⚡ Enabling CallIn service in container '{container_name}'...")
+
+        # Call enable callin utility
+        success, message = enable_callin_service(
+            container_name=container_name,
+            timeout=timeout
+        )
+
+        if success:
+            click.echo(f"✓ CallIn service enabled in container '{container_name}'")
+            click.echo(f"  {message}")
+            ctx.exit(0)
+        else:
+            progress.print_error(f"Failed to enable CallIn service:\n{message}")
+            ctx.exit(1)
+
+    except (ImportError, ModuleNotFoundError) as e:
+        progress.print_error(f"enable_callin utility not available: {e}")
+        ctx.exit(1)
+    except (click.exceptions.Exit, SystemExit, KeyboardInterrupt):
+        # Let Click handle these - don't catch them
+        raise
+    except Exception as e:
+        progress.print_error(f"Failed to enable CallIn: {e}")
+        ctx.exit(1)
